SAL Mycelium - Client interface for interacting with Mycelium node’s HTTP API
This crate provides a client interface for interacting with a Mycelium node’s HTTP API.
Mycelium is a decentralized networking project, and this SAL module allows Rust applications
and herodo Rhai scripts to manage and communicate over a Mycelium network.
The module enables operations such as:
- Querying node status and information
- Managing peer connections (listing, adding, removing)
- Inspecting routing tables (selected and fallback routes)
- Sending messages to other Mycelium nodes
- Receiving messages from subscribed topics
All interactions with the Mycelium API are performed asynchronously.
Modules
- rhai
- Rhai wrappers for Mycelium client module functions
Functions
- add_
peer - Add a new peer to the Mycelium node
- get_
node_ info - Get information about the Mycelium node
- list_
fallback_ routes - List all fallback routes in the Mycelium node
- list_
peers - List all peers connected to the Mycelium node
- list_
selected_ routes - List all selected routes in the Mycelium node
- receive_
messages - Receive messages from a topic via the Mycelium node
- remove_
peer - Remove a peer from the Mycelium node
- send_
message - Send a message to a destination via the Mycelium node